@@ -13,11 +13,13 @@
 #include "txtif.h"
 #include "conf.h"
 
+#include "hosts.h"
 
-void main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	TxtIF *txtif;
 	Conf gconf;
+	Hosts hosts;
 	int fd;
 	char tmp[200], *p;
 
@@ -26,11 +28,17 @@ void main(int argc, char *argv[])
 		strcat(tmp, p);
 		strcat(tmp, "/.qftprc");	
 		fd = open(tmp, O_RDONLY);
-		gconf.Parse(fd);
+		hosts.Parse(fd, gconf);
 		close(fd);
 	}
-	txtif = new TxtIF(new FtpConn, gconf);
-	if (argc > 1)
+	gconf.Parse(gconf, argc, argv, "abcefhlnqzy:u:ABCEFLNQZ");
+	txtif = new TxtIF(new FtpConn, gconf, &hosts);
+	if (argv[1] && argv[1][0] == '-' && argv[1][1] == 'h') {
+		txtif->Khelp(-1, argv);
+		exit(0);
+	}
+	if (gconf.Args())
 		txtif->Open(argc, argv);
 	txtif->go();
+	return 0;
 }
