@@ -11,8 +11,9 @@
 #include "conf.h"
 #include "flist.h"
 #include "ftpconn.h"
+#include "hosts.h"
 
-#define PAGER "/usr/bin/less"
+#define PAGER "less"
 
 struct options {
 	char bg;	// b
@@ -30,20 +31,27 @@ struct options {
 class TxtIF {
 	FtpConn *ftp;
 	Conf gconf;
+	Hosts *hosts;
 	char user[128], pass[128], anonuser[128], anonpass[128];
 	struct options opts;
 	char prompt[1024];
-	FileList curList;
+	DirList curList;
+	DirList markList;
+	
 	int Get(Conf &conf, char *p, FtpConn *nftp = NULL);
+	int Expand(int &n, char *a[]);
+	void Glob(char *, DirList&, int glob = 0);
  public:
 	TxtIF();
-	TxtIF(FtpConn *ftp, Conf &nconf);
+	TxtIF(FtpConn *ftp, Conf &nconf, Hosts *hosts);
 	void go();
 	int lookup(char *s);
-	int procargs(char *s, char *a[]);
 	int Khelp(int n, char *a[]);
 	int Open(int n, char *a[]);
 	int Close(int n, char *a[]);
+	int Mark(int n, char *a[]);
+	int GetMarked(int n, char *a[]);
+	int ListMarked(int n, char *a[]);
 	int List(int n, char *a[]);
 	int LongList(int n, char *a[]);
 	int Cd(int n, char *a[]);
